diff --git a/doc/config.rst b/doc/config.rst
index 1df8eea55cd3efff6c9e3a1bd1bb2c9f5290812a..198356f10964001807645c6c9a4a0f653e8fdf09 100644
--- a/doc/config.rst
+++ b/doc/config.rst
@@ -58,12 +58,17 @@ not set by default.
 .. _config-email:
 
 EMAIL
-  The email address used in contact information on the website, as sender in
-  batch job notifications, and in communication with the NCBI webservices
-  using Entrez.
+  The email address used in contact information on the website and sent with
+  NCBI Entrez calls.
 
   `Default value:` ``mutalyzer@humgen.nl``
 
+BATCH_NOTIFICATION_EMAIL
+  The email address used as sender in batch job notifications. If set to
+  `None`, the value of :ref:`EMAIL <config-email>` will be used.
+
+  `Default value:` `None`
+
 .. _config-debug:
 
 DEBUG
diff --git a/mutalyzer/Scheduler.py b/mutalyzer/Scheduler.py
index 96db9f0799c42728d35be685f174c82ddd310fe8..81d952e4501e53a69eb39a649bfaed422cdc8692 100644
--- a/mutalyzer/Scheduler.py
+++ b/mutalyzer/Scheduler.py
@@ -106,6 +106,7 @@ class Scheduler() :
         #TODO: Handle Connection errors in a try, except clause
         #Expected errors: socket.error
 
+        from_address = settings.BATCH_NOTIFICATION_EMAIL or settings.EMAIL
         download_url = website.url_for('batch_job_result',
                                        result_id=result_id)
 
@@ -123,7 +124,7 @@ With kind regards,
 Mutalyzer batch scheduler""" % download_url)
 
         message["Subject"] = "Result of your Mutalyzer batch job"
-        message["From"] = settings.EMAIL
+        message["From"] = from_address
         message["To"] = mailTo
 
         try:
@@ -138,7 +139,7 @@ Mutalyzer batch scheduler""" % download_url)
             return
 
         try:
-            smtpInstance.sendmail(settings.EMAIL, mailTo, message.as_string())
+            smtpInstance.sendmail(from_address, mailTo, message.as_string())
         except smtplib.SMTPRecipientsRefused as e:
             for address, (code, error) in e.recipients.items():
                 print 'Could not send email to %s: (%s) %s' % (address,
diff --git a/mutalyzer/config/default_settings.py b/mutalyzer/config/default_settings.py
index 4007fd0a5fc819099af9454d49b0e93153dfde36..5f3e6e05b4f2eb64c0de4e192abb8a59b8499c83 100644
--- a/mutalyzer/config/default_settings.py
+++ b/mutalyzer/config/default_settings.py
@@ -13,11 +13,14 @@ DEBUG = False
 # We are running unit tests.
 TESTING = False
 
 # This address is used in contact information on the website, as sender in
 # batch job notifications, and with retrieval of records at the NCBI using
 # Entrez.
 EMAIL = 'mutalyzer@humgen.nl'
 
+# This email address is used as sender in batch job notifications. If `None`,
+# the value of `EMAIL` will be used.
+BATCH_NOTIFICATION_EMAIL = None
+
 # The cache directory. Used to store uploaded and downloaded files (e.g.,
 # reference files from NCBI or user) and batch job results.
 CACHE_DIR = '/tmp'
@@ -13,11 +13,14 @@ DEBUG = False
 TESTING = False
 
-# This address is used in contact information on the website, as sender in
-# batch job notifications, and with retrieval of records at the NCBI using
-# Entrez.
+# This email address is used in contact information on the website and sent
+# with NCBI Entrez calls.
 EMAIL = 'mutalyzer@humgen.nl'
 